##  Application Run Cost Broken Down by Business Capability
This second panel helps you track the run cost of your applications as provided by the "Total annual cost" field on the relation between IT components and applications.
![2032](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274fb27f7a441014a8cedadef62bd9c8_LowRes.png)
Example of the application "HR Admin" that is running on an IT Component with a total annual cost specified.
On the panel, users can review the total costs and costs grouped by the different business capabilities.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2741734c7a441014b29da6d0be6bebff_LowRes.png)
